Learn R Programming

accrued (version 1.4)

print.accrued: Print function for objects of the accrued class.

Description

Prints partially accruing data objects of the accrued class.

Usage

"print"(x, ...)

Arguments

x
Object of the accrued class.
...
Parameters to pass to print.default or plot.

Value

Details

print.accrued displays a matrix of counts with columns representing the lag and rows the encounter date.

Examples

Run this code
	data(accruedDataExample)
	testData <- data.accrued(accruedDataExample)

	testData					# print.accrued

Run the code above in your browser using DataLab