Learn R Programming

accrued (version 1.4.1)

summary.accrued: Print and summary functions for objects of the accrued class.

Description

Functions to display and summarize (as text or as a plot) partially accruing data objects of the accrued class.

Usage

"summary"(object, ...)

Arguments

object
Object of the accrued class.
...
Parameters to pass to print.default or plot.

Value

summary.accrued invisibly returns an object of the summary.accrued class, consisting of a list with the following components:

Details

summary.accrued creates a summary object (of class summary.accrued) of the counts consisting of the percentage of days on which an upload was recevied for each lag, the mean proportion of counts received by each lag, and the mean counts received by each lag.

Examples

Run this code
	data(accruedDataExample)
	testData <- data.accrued(accruedDataExample)
	summ_dat = summary(testData)		# summary.accrued object

Run the code above in your browser using DataLab