print.summary.accrued: Print function for objects of the summary.accrued class.
Description
Displays as text summarized partially accruing data objects of the summary.accrued class.
Usage
"print"(x, ...)
Arguments
x
Object of class summary.data.accrued.
...
Parameters to pass to print.
Value
Details
print.summary.accrued prints to the screen the contents of a summary.accrued object, namely, the counts consisting of the percentage of days on
which an upload was recevied for each lag, the mean proportion of counts received by each lag,
and the mean counts received by each lag.