print.summary.accrued: Print function for objects of the summary.accrued class.
Description
Functions to display as text summarized partially accrued data objects of the summary.accrued class.
Usage
## S3 method for class 'summary.accrued':
print(x, \dots)
Arguments
x
Object of class summary.data.accrued.
...
Parameters to pass to print.
Value
None.
Details
print.summary.accrued prints to the screen the contents of a summary.accrued object, namely, the counts consisting of the percentage of days on
which an upload was recevied for each lag, the mean proportion of counts received by each lag,
and the mean counts received by each lag.